# Generated by Django 2.0.13 on 2019-08-05 08:25

from django.db import migrations


def increment_stage_in_forms(forms):
    """
    The current system has assumption that there is one application form per stage.
    To replicate the current behaviour new stage field should be equal to the index of the form.
    """
    for index, form in enumerate(forms.all(), 1):
        form.stage = index
        form.save(update_fields=["stage"])


def one_application_form_per_stage(apps, schema_editor):
    Fund = apps.get_model("funds", "FundType")
    RequestForPartners = apps.get_model("funds", "RequestForPartners")
    Round = apps.get_model("funds", "Round")
    SealedRound = apps.get_model("funds", "SealedRound")
    LabType = apps.get_model("funds", "LabType")

    for fund in Fund.objects.all():
        if fund.forms.count() > 1:
            increment_stage_in_forms(fund.forms)

    for rfp in RequestForPartners.objects.all():
        if rfp.forms.count() > 1:
            increment_stage_in_forms(rfp.forms)

    for round_ in Round.objects.all():
        if round_.forms.count() > 1:
            increment_stage_in_forms(round_.forms)

    for sealed_round in SealedRound.objects.all():
        if sealed_round.forms.count() > 1:
            increment_stage_in_forms(sealed_round.forms)

    for lab in LabType.objects.all():
        if lab.forms.count() > 1:
            increment_stage_in_forms(lab.forms)


class Migration(migrations.Migration):
    dependencies = [
        ("funds", "0066_add_stage_to_selected_forms"),
    ]

    operations = [
        migrations.RunPython(one_application_form_per_stage, migrations.RunPython.noop),
    ]
